@@ -1,4 +1,4 @@
-from pyug import get_random_name
+from pyug import get_random_username
 from argparse import ArgumentParser
 
 
@@ -8,4 +8,4 @@ if __name__ == '__main__':
     a = ap.parse_args()
 
     for _ in range(a.count):
-        print(get_random_name())
+        print(get_random_username())
